@@ -38,6 +38,7 @@ class BaseDocumentCloudClient(object):
         self.username = username
         self.password = password
     
+    @retry(Exception, tries=4)
     def _make_request(self, url, params=None, opener=None):
         """
         Configure a HTTP request, fire it off and return the response.
@@ -266,7 +267,8 @@ class DocumentClient(BaseDocumentCloudClient):
         # Loop through the path and get all the files
         path_list = []
         for (dirpath, dirname, filenames) in os.walk(path):
-            path_list.extend([os.path.join(dirpath, i) for i in filenames if i.endswith(".pdf")])
+            path_list.extend([os.path.join(dirpath, i) for i in filenames
+                if i.lower().endswith(".pdf")])
         # Upload all the pdfs
         obj_list = []
         for pdf_path in path_list:
